@@ -22,7 +22,7 @@
     if (!is.logical(setSEED)){
         stop(" setSEED must be logical")
     }
-    if (!(class(tsmethod)=="character" & (tsmethod=="central" | tsmethod=="abs"))){
+    if (!(inherits(tsmethod,what="character") & (tsmethod=="central" | tsmethod=="abs"))){
         stop(" tsmethod must be 'central' or 'abs' ")
     }
 
